"use client";

import Link from "next/link";
import { Button } from "@/components/ui/button";
import { Users, UserCog, BarChart3 } from "lucide-react";
import Image from "next/image";
import { useAuth } from "@/lib/hooks/useAuth";
import { useEffect, useState } from "react";
import { useRouter } from "next/navigation";

export default function Home() {
  const { user, loading } = useAuth();
  const router = useRouter();
  const [isClient, setIsClient] = useState(false);

  useEffect(() => {
    setIsClient(true);
    // If user is logged in, redirect to dashboard
    if (user && !loading) {
      router.push('/dashboard');
    }
  }, [user, loading, router]);

  // Show loading state while checking auth status
  if (loading || !isClient) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
      </div>
    );
  }

  return (
    <div className="min-h-screen flex flex-col">
      {/* Hero section */}
      <div className="flex-1 flex flex-col items-center justify-center text-center px-4 py-12 md:py-24">
        <div className="h-46 w-46 rounded-full bg-primary flex items-center justify-center mb-6 animate-bounce">
          <Image
            src="/logo1.png"
            alt="Dadaz Logo"
            width={150}
            height={150}
            className="h-30 w-auto"
          />
        </div>
        <h1 className="text-4xl md:text-6xl font-bold tracking-tight mb-4">
          Dadaz Center
        </h1>
        <p className="text-xl md:text-2xl text-muted-foreground mb-8 max-w-2xl">
          A comprehensive school management system developed by Senlain systems for tracking students, teachers, classes, and attendance
        </p>
        <div className="flex gap-4">
          <Link href="/auth">
            <Button size="lg" className="h-12 px-6">
              Get Started
            </Button>
          </Link>
        </div>
      </div>

      {/* Features section - Only show to public users */}
      {!user && (
        <div className="bg-muted py-16 px-4">
          <div className="max-w-7xl mx-auto">
            <h2 className="text-3xl font-bold text-center mb-12">
              Comprehensive School Management
            </h2>
            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              <div className="bg-card p-6 rounded-lg shadow-sm">
                <div className="h-12 w-12 rounded-full bg-primary/10 flex items-center justify-center mb-4">
                  <Users className="h-6 w-6 text-primary" />
                </div>
                <h3 className="text-xl font-bold mb-2">Student Management</h3>
                <p className="text-muted-foreground">
                  Manage student profiles, track academic progress, and monitor attendance with ease.
                </p>
              </div>
              <div className="bg-card p-6 rounded-lg shadow-sm">
                <div className="h-12 w-12 rounded-full bg-primary/10 flex items-center justify-center mb-4">
                  <UserCog className="h-6 w-6 text-primary" />
                </div>
                <h3 className="text-xl font-bold mb-2">Teacher Management</h3>
                <p className="text-muted-foreground">
                  Organize teacher information, class assignments, and professional qualifications.
                </p>
              </div>
              <div className="bg-card p-6 rounded-lg shadow-sm">
                <div className="h-12 w-12 rounded-full bg-primary/10 flex items-center justify-center mb-4">
                  <BarChart3 className="h-6 w-6 text-primary" />
                </div>
                <h3 className="text-xl font-bold mb-2">Advanced Analytics</h3>
                <p className="text-muted-foreground">
                  Gain insights with powerful reporting tools and visual analytics for attendance and performance.
                </p>
              </div>
            </div>
          </div>
        </div>
      )}

      {/* Footer */}
      <footer className="py-6 border-t">
        <div className="max-w-7xl mx-auto px-4 flex flex-col md:flex-row justify-between items-center">
          <div className="flex items-center mb-4 md:mb-0">
            <Image
              src="/logo1.png"
              alt="Dadaz Logo"
              width={120}
              height={40}
              className="h-20 w-auto"
            />
            <span className="font-bold">Dadaz Center</span>
          </div>
          <p className="text-sm text-muted-foreground">
            © {new Date().getFullYear()} Dadaz Center. All rights reserved.
          </p>
        </div>
      </footer>
    </div>
  );
}